@@ -6,7 +6,7 @@ use shtola::log::*;
 use shtola::plugins;
 use shtola::Shtola;
 
-const VERSION: &'static str = "0.5.3";
+const VERSION: &'static str = "0.5.4";
 
 #[derive(FromArgs)]
 /// A static site generator.
@@ -75,6 +75,9 @@ fn main() {
 	if !args.ignored_plugins.contains(&"tera_layouts".to_string()) {
 		sh.register(plugins::tera_layouts::plugin());
 	}
+	if !args.ignored_plugins.contains(&"pretty_links".to_string()) {
+		sh.register(plugins::pretty_links::plugin());
+	}
 
 	sh.build().unwrap();
 	info!(
